--[[
Specialization for the automatic bale loading of the Fliegl DPW 180.

Source: UBT Script

Author: Ifko[nator]
Date: 09.07.2015
Version: 2.0

History: V 1.0 @ 13.06.2015 - intial release
		 V 1.1 @ 15.06.2015 - hot fix - move ALL text's to the helpbox
		 V 1.2 @ 20.06.2015 - added warning texts, speed limit and help unloading lines
		 V 1.5 @ 30.06.2015 - added Couresplay support - Thanks to Thomas Gärtner for helping
		 V 2.0 @ 09.07.2015 - added Ros Transportboxes - Link: http://www.modhoster.de/mods/ros-transport-und-lagerbox

Website: http://www.modding-welt.com/index.php/BoardList
]]

FlieglDPW180 = {};

function FlieglDPW180.prerequisitesPresent(specializations)
    return true;
end;

function FlieglDPW180:load(xmlFile)
	self.automaticLoading = false;
	
	self.automaticLoadingText = {
		g_i18n:getText("AUTOLOAD_MANUAL"), 
		g_i18n:getText("AUTOLOAD_AUTOMATIC")
	};
	
	self.loadingIsActive = false;
	self.showFlieglHelp = false;
	
	--Courseplay identifier
	self.isSpecialBaleLoader = true;
	self.isFlieglDPWxxx = true;
	self.unloadingIsActive = false;
	self.isLookingForBales = false;
	
	self.maxSpeedLimit = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.flieglDPW180#maxSpeedLimit"), 25);
	
	self.warningText = {
		g_i18n:getText("TO_UNLOAD_STOP_AUTOLOAD"), 
		g_i18n:getText("TO_CHANGE_UNLOAD_SIDE_STOP_AUTOLOAD"), 
		g_i18n:getText("TO_CHANGE_BALETYPE_UNLOAD"), 
		g_i18n:getText("TO_CHANGE_LOADINGTYPE_STOP_AUTOLOAD"),
		string.format(g_i18n:getText("TO_FAST_DRIVEN_AUTOLOAD_WAS_STOPPED"), self.maxSpeedLimit),
		string.format(g_i18n:getText("YOU_DRIVE_TO_FAST_TO_LOAD"), self.maxSpeedLimit)
	};
	
	self.maxSpeedLimit = self.maxSpeedLimit + 1;
	
	self.showWarning = false;
	self.warning1 = false;
	self.warning2 = false;
	self.warning3 = false;
	self.warning4 = false;
	self.warning5 = false;
	self.warning6 = false;
	
	self.unloadLeft = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.unload#leftIndex"));
	self.unloadRight = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.unload#rightIndex"));
	self.unloadBack = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.unload#backIndex"));
	
	self.showUnloadingHelp = false;
	
	self.helpLineLeftStart = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.helpLines.left#startIndex"));
	self.helpLineLeftEnd = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.helpLines.left#endIndex"));
	self.helpLineLeftStart2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.helpLines.left#startIndex2"));
	self.helpLineLeftEnd2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.helpLines.left#endIndex2"));
	
	self.helpLineRightStart = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.helpLines.right#startIndex"));
	self.helpLineRightEnd = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.helpLines.right#endIndex"));
	self.helpLineRightStart2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.helpLines.right#startIndex2"));
	self.helpLineRightEnd2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.helpLines.right#endIndex2"));
	
	self.helpLineBackStart = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.helpLines.back#startIndex"));
	self.helpLineBackEnd = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.helpLines.back#endIndex"));
	self.helpLineBackStart2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.helpLines.back#startIndex2"));
	self.helpLineBackEnd2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.helpLines.back#endIndex2"));
	
	self.colorRed = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.flieglDPW180.helpLines.colors#red"), 0.95);
	self.colorGreen = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.flieglDPW180.helpLines.colors#green"), 0);
	self.colorBlue = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.flieglDPW180.helpLines.colors#blue"), 0);
	
	self.nearestDistance = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.flieglDPW180#nearestDistance"), 10);
	
	self.unloadSide = 1;
	self.currentUnloadSide = {
		{g_i18n:getText("UNLOAD_LEFT"), false, self.unloadLeft},
		{g_i18n:getText("UNLOAD_BACK"), false, self.unloadBack},
		{g_i18n:getText("UNLOAD_RIGHT"), false, self.unloadRight},
		{g_i18n:getText("UNLOAD_TRAILER"), false, 0}
	};	
	
	self.updateCounter = 1;
	
	self.productType = 1;
	
	self.numFlieglDPW180Types = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.flieglDPW180#count"), 0);
	self.numProducts = {};
	self.attacher = {};
	self.attacherLevel = {};
	self.choosenProductType = {};
	
	for i = 1, self.numFlieglDPW180Types do
		self.numProducts[i] = Utils.getNoNil(getXMLInt(xmlFile, string.format("vehicle.flieglDPW180.product" .. "%d" .. "#count", i)), 0);
		self.choosenProductType[i] = {g_i18n:getText(Utils.getNoNil(getXMLString(xmlFile, string.format("vehicle.flieglDPW180.product" .. "%d" .. "#type", i))), "nil"), i};
		self.attacher[i] = {};
		self.attacherLevel[i] = Utils.indexToObject(self.components, getXMLString(xmlFile, string.format("vehicle.flieglDPW180.product" .. "%d" .. "#index", i)));
		for j = 1,self.numProducts[i] do
			self.attacher[i][j] = {};
			local partName = string.format("vehicle.flieglDPW180.product" .. "%d" .. ".productAttacher" .. "%d", i, j);
			self.attacher[i][j].object = Utils.indexToObject(self.components, getXMLString(xmlFile, partName .. "#index"));
			self.attacher[i][j].attachedProduct = nil;
			self.attacher[i][j].productInRange = nil;
		end;
	end;
	
    self.capacity = self.numProducts[self.productType];
	
	self.spanngurt = {};
	
	self.spanngurt.quaderballen = {};
	self.spanngurt.quaderballen.ballen1 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen1#index"));
	self.spanngurt.quaderballen.ballen2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen2#index"));
	self.spanngurt.quaderballen.ballen3 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen3#index"));
	self.spanngurt.quaderballen.ballen4 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen4#index"));
	self.spanngurt.quaderballen.ballen5 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen5#index"));
	self.spanngurt.quaderballen.ballen6 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen6#index"));
	self.spanngurt.quaderballen.ballen7 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen7#index"));
	self.spanngurt.quaderballen.ballen8 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen8#index"));
	self.spanngurt.quaderballen.ballen9 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen9#index"));
	self.spanngurt.quaderballen.ballen10 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen10#index"));
	self.spanngurt.quaderballen.ballen11 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen11#index"));
	self.spanngurt.quaderballen.ballen12 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen12#index"));
	self.spanngurt.quaderballen.ballen13 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen13#index"));
	self.spanngurt.quaderballen.ballen14 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen14#index"));
	self.spanngurt.quaderballen.ballen15 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen15#index"));
	self.spanngurt.quaderballen.ballen16 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen16#index"));
	self.spanngurt.quaderballen.ballen17 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen17#index"));
	self.spanngurt.quaderballen.ballen18 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen18#index"));
	self.spanngurt.quaderballen.ballen19 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen19#index"));
	self.spanngurt.quaderballen.ballen20 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen20#index"));
	self.spanngurt.quaderballen.ballen21 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen21#index"));
	self.spanngurt.quaderballen.ballen22 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen22#index"));
	self.spanngurt.quaderballen.ballen23 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen23#index"));
	self.spanngurt.quaderballen.ballen24 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteQuaderballen.ballen24#index"));
	
	self.spanngurt.rundballen = {};
	self.spanngurt.rundballen.ballen1 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen1#index"));
	self.spanngurt.rundballen.ballen2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen2#index"));
	self.spanngurt.rundballen.ballen3 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen3#index"));
	self.spanngurt.rundballen.ballen4 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen4#index"));
	self.spanngurt.rundballen.ballen5 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen5#index"));
	self.spanngurt.rundballen.ballen6 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen6#index"));
	self.spanngurt.rundballen.ballen7 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen7#index"));
	self.spanngurt.rundballen.ballen8 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen8#index"));
	self.spanngurt.rundballen.ballen9 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen9#index"));
	self.spanngurt.rundballen.ballen10 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen10#index"));
	self.spanngurt.rundballen.ballen11 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen11#index"));
	self.spanngurt.rundballen.ballen12 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen12#index"));
	self.spanngurt.rundballen.ballen13 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen13#index"));
	self.spanngurt.rundballen.ballen14 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen14#index"));
	self.spanngurt.rundballen.ballen15 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen15#index"));
	self.spanngurt.rundballen.ballen16 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen16#index"));
	self.spanngurt.rundballen.ballen17 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen17#index"));
	self.spanngurt.rundballen.ballen18 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen18#index"));
	self.spanngurt.rundballen.ballen19 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen19#index"));
	self.spanngurt.rundballen.ballen20 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen20#index"));
	self.spanngurt.rundballen.ballen21 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen21#index"));
	self.spanngurt.rundballen.ballen22 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen22#index"));
	self.spanngurt.rundballen.ballen23 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen23#index"));
	self.spanngurt.rundballen.ballen24 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen24#index"));
	self.spanngurt.rundballen.ballen25 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen25#index"));
	self.spanngurt.rundballen.ballen26 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen26#index"));
	self.spanngurt.rundballen.ballen27 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen27#index"));
	self.spanngurt.rundballen.ballen28 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen28#index"));
	self.spanngurt.rundballen.ballen29 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen29#index"));
	self.spanngurt.rundballen.ballen30 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteRundballen.ballen30#index"));
	
	self.spanngurt.wollpaletten = {};
	self.spanngurt.wollpaletten.palette1 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteWollpaletten.palette1#index"));
	self.spanngurt.wollpaletten.palette2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteWollpaletten.palette2#index"));
	self.spanngurt.wollpaletten.palette3 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteWollpaletten.palette3#index"));
	self.spanngurt.wollpaletten.palette4 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteWollpaletten.palette4#index"));
	self.spanngurt.wollpaletten.palette5 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteWollpaletten.palette5#index"));
	self.spanngurt.wollpaletten.palette6 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteWollpaletten.palette6#index"));
	self.spanngurt.wollpaletten.palette7 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteWollpaletten.palette7#index"));
	self.spanngurt.wollpaletten.palette8 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteWollpaletten.palette8#index"));
	self.spanngurt.wollpaletten.palette9 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteWollpaletten.palette9#index"));
	self.spanngurt.wollpaletten.palette10 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteWollpaletten.palette10#index"));
	self.spanngurt.wollpaletten.palette11 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteWollpaletten.palette11#index"));
	self.spanngurt.wollpaletten.palette12 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteWollpaletten.palette12#index"));
	
	self.spanngurt.baumsetzlingpaletten = {};
	self.spanngurt.baumsetzlingpaletten.palette1 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteBaumsetzlingpaletten.palette1#index"));
	self.spanngurt.baumsetzlingpaletten.palette2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteBaumsetzlingpaletten.palette2#index"));
	self.spanngurt.baumsetzlingpaletten.palette3 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteBaumsetzlingpaletten.palette3#index"));
	self.spanngurt.baumsetzlingpaletten.palette4 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteBaumsetzlingpaletten.palette4#index"));
	self.spanngurt.baumsetzlingpaletten.palette5 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteBaumsetzlingpaletten.palette5#index"));
	self.spanngurt.baumsetzlingpaletten.palette6 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteBaumsetzlingpaletten.palette6#index"));
	self.spanngurt.baumsetzlingpaletten.palette7 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteBaumsetzlingpaletten.palette7#index"));
	self.spanngurt.baumsetzlingpaletten.palette8 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteBaumsetzlingpaletten.palette8#index"));
	self.spanngurt.baumsetzlingpaletten.palette9 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteBaumsetzlingpaletten.palette9#index"));
	self.spanngurt.baumsetzlingpaletten.palette10 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteBaumsetzlingpaletten.palette10#index"));
	self.spanngurt.baumsetzlingpaletten.palette11 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteBaumsetzlingpaletten.palette11#index"));
	self.spanngurt.baumsetzlingpaletten.palette12 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteBaumsetzlingpaletten.palette12#index"));
	
	self.spanngurt.holzpaletten = {};
	self.spanngurt.holzpaletten.palette1 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteHolzpaletten.palette1#index"));
	self.spanngurt.holzpaletten.palette2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteHolzpaletten.palette2#index"));
	self.spanngurt.holzpaletten.palette3 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteHolzpaletten.palette3#index"));
	self.spanngurt.holzpaletten.palette4 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteHolzpaletten.palette4#index"));
	self.spanngurt.holzpaletten.palette5 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteHolzpaletten.palette5#index"));
	self.spanngurt.holzpaletten.palette6 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteHolzpaletten.palette6#index"));
	self.spanngurt.holzpaletten.palette7 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteHolzpaletten.palette7#index"));
	self.spanngurt.holzpaletten.palette8 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteHolzpaletten.palette8#index"));
	
	self.spanngurt.kartoffelpaletten = {};
	self.spanngurt.kartoffelpaletten.palette1 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteKartoffelpaletten.palette1#index"));
	self.spanngurt.kartoffelpaletten.palette2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteKartoffelpaletten.palette2#index"));
	self.spanngurt.kartoffelpaletten.palette3 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteKartoffelpaletten.palette3#index"));
	self.spanngurt.kartoffelpaletten.palette4 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteKartoffelpaletten.palette4#index"));
	self.spanngurt.kartoffelpaletten.palette5 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteKartoffelpaletten.palette5#index"));
	self.spanngurt.kartoffelpaletten.palette6 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteKartoffelpaletten.palette6#index"));
	self.spanngurt.kartoffelpaletten.palette7 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteKartoffelpaletten.palette7#index"));
	self.spanngurt.kartoffelpaletten.palette8 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteKartoffelpaletten.palette8#index"));
	self.spanngurt.kartoffelpaletten.palette9 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteKartoffelpaletten.palette9#index"));
	self.spanngurt.kartoffelpaletten.palette10 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteKartoffelpaletten.palette10#index"));
	self.spanngurt.kartoffelpaletten.palette11 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteKartoffelpaletten.palette11#index"));
	self.spanngurt.kartoffelpaletten.palette12 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteKartoffelpaletten.palette12#index"));
	
	self.spanngurt.transportboxen = {};
	self.spanngurt.transportboxen.box1 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box1#index"));
	self.spanngurt.transportboxen.box2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box2#index"));
	self.spanngurt.transportboxen.box3 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box3#index"));
	self.spanngurt.transportboxen.box4 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box4#index"));
	self.spanngurt.transportboxen.box5 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box5#index"));
	self.spanngurt.transportboxen.box6 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box6#index"));
	self.spanngurt.transportboxen.box7 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box7#index"));
	self.spanngurt.transportboxen.box8 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box8#index"));
	self.spanngurt.transportboxen.box9 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box9#index"));
	self.spanngurt.transportboxen.box10 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box10#index"));
	self.spanngurt.transportboxen.box11 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box11#index"));
	self.spanngurt.transportboxen.box12 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box12#index"));
	self.spanngurt.transportboxen.box13 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box13#index"));
	self.spanngurt.transportboxen.box14 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box14#index"));
	self.spanngurt.transportboxen.box15 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box15#index"));
	self.spanngurt.transportboxen.box16 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box16#index"));
	self.spanngurt.transportboxen.box17 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box17#index"));
	self.spanngurt.transportboxen.box18 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box18#index"));
	self.spanngurt.transportboxen.box19 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box19#index"));
	self.spanngurt.transportboxen.box20 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flieglDPW180.spanngurte.spanngurteTransportboxen.box20#index"));
end;

function FlieglDPW180:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)
	if not resetVehicles then
		local productType = Utils.getNoNil(getXMLInt(xmlFile, key .. "#productType"), self.productType);
		local unloadSide = Utils.getNoNil(getXMLInt(xmlFile, key .. "#unloadSide"), self.unloadSide);
		local automaticLoading = Utils.getNoNil(getXMLBool(xmlFile, key.. "#automaticLoading"), self.automaticLoading);
		local showFlieglHelp = Utils.getNoNil(getXMLBool(xmlFile, key .. "#showFlieglHelp"), self.showFlieglHelp);
		local showUnloadingHelp = Utils.getNoNil(getXMLBool(xmlFile, key .. "#showUnloadingHelp"), self.showUnloadingHelp);
	
		self.productType = productType;
		self.capacity = self.numProducts[self.productType];
		self.fillLevel = 0;
		self.unloadSide = unloadSide;
		self.automaticLoading = automaticLoading;
		self.showFlieglHelp = showFlieglHelp;
		self.showUnloadingHelp = showUnloadingHelp;
	end; 

    return BaseMission.VEHICLE_LOAD_OK;
end;

function FlieglDPW180:getSaveAttributesAndNodes(nodeIdent)
	self.backMode = self.currentUnloadSide[self.unloadSide][1]
	
	if self.fillLevel > 0 then
		self.currentUnloadSide[self.unloadSide][1] = g_i18n:getText("UNLOAD_TRAILER");
		for i = 1, self.fillLevel do
			if self.attacher[self.productType][i].attachedProduct ~= nil then
				FlieglDPW180:ProductDetachFlieglDPW180(self,i);
				self.fillLevel = self.fillLevel - 1;
			end;
			self.fillLevel = 0;
		end;
	end;
	self.currentUnloadSide[self.unloadSide][1] = self.backMode
	
	if self.loadingIsActive then
		self.loadingIsActive = false;
	end;
	
	local attributes = 
		'productType="' .. tostring(self.productType) ..
		'" unloadSide="' .. tostring(self.unloadSide) ..
		'" automaticLoading="' .. tostring(self.automaticLoading) ..
		'" showFlieglHelp="' .. tostring(self.showFlieglHelp) ..
		'" showUnloadingHelp="' .. tostring(self.showUnloadingHelp) ..
	'"';
	
	return attributes, nil;
end;


function FlieglDPW180:delete()
	self.currentUnloadSide[self.unloadSide][1] = g_i18n:getText("UNLOAD_TRAILER");
	if self.fillLevel > 0 then
		for i = 1, self.fillLevel do
			if self.attacher[self.productType][i].attachedProduct ~= nil then
				FlieglDPW180:ProductDetachFlieglDPW180(self,i);
				self.fillLevel = self.fillLevel - 1;
			end;
		end;
		self.fillLevel = 0;
	end;
	
	if self.loadingIsActive then
		self.loadingIsActive = false;
	end;
end;

function FlieglDPW180:mouseEvent(posX, posY, isDown, isUp, button)
end;

function FlieglDPW180:keyEvent(unicode, sym, modifier, isDown)
end;

function FlieglDPW180:update(dt)
	self.showWarning = false;
	self.warning1 = false;
	self.warning2 = false;
	self.warning3 = false;
	self.warning4 = false;
	self.warning5 = false;
	self.warning6 = false;

	local maxSpeedLimit = self.maxSpeedLimit/3600;
	
	if self.lastSpeedReal > maxSpeedLimit and self.loadingIsActive then
		self.loadingIsActive = false;
		self.showWarning = true;
		self.warning5 = true;
	end;
	
	if self:getIsActiveForInput() or self.unloadingIsActive then
		if InputBinding.hasEvent(InputBinding.FLIEGL_DPW180_LOAD) then 
			if not self.automaticLoading then
				if self.lastSpeedReal < maxSpeedLimit then
					for i = 1, self.numProducts[self.productType] do
						if self.attacher[self.productType][i].attachedProduct == nil then
							local nearest = FlieglDPW180:ProductInRangeFlieglDPW180(self, i);
							if nearest ~= nil then
								self.attacher[self.productType][i].productInRange = nearest;
								FlieglDPW180:ProductAttachFlieglDPW180(self, i);
							else
								break;
							end;
						end;
					end;
				else
					self.showWarning = true;
					self.warning6 = true;
				end;
			else
				self.loadingIsActive = not self.loadingIsActive;
			end;
		end;
		
		if InputBinding.hasEvent(InputBinding.FLIEGL_DPW180_UNLOAD) or self.unloadingIsActive then
			if not self.loadingIsActive then
				for k = 1, self.numProducts[self.productType] do
					if self.attacher[self.productType][k].attachedProduct ~= nil then
						FlieglDPW180:ProductDetachFlieglDPW180(self, k);
						self.fillLevel = self.fillLevel - 1;
					end;
				end;
				self.fillLevel = 0;
			else
				self.showWarning = true;
				self.warning1 = true;
			end;
			self.unloadingIsActive = false
		end;
		
		if InputBinding.hasEvent(InputBinding.FLIEGL_DPW180_TOGGLE_UNLOAD_SIDE) then
			if not self.loadingIsActive then
				if self.unloadSide == 4 then
					self.unloadSide = 0;
				end;
				self.unloadSide = self.unloadSide + 1;
			else
				self.showWarning = true;
				self.warning2 = true;
			end;
		end;
		
		if InputBinding.hasEvent(InputBinding.FLIEGL_DPW180_TOGGLE_PRODUCT_TYPE) then
			if self.fillLevel == 0 then
				if self.productType == #(self.numProducts) then
					self.productType = 0;
				end;
				self.productType = self.productType + 1;
				self.capacity = self.numProducts[self.productType];
			else
				self.showWarning = true;
				self.warning3 = true;
			end;
		end;
		
		if InputBinding.hasEvent(InputBinding.FLIEGL_DPW180_TOGGLE_LOADING_TYPE) then
			if not self.loadingIsActive then
				self.automaticLoading = not self.automaticLoading
			else
				self.showWarning = true;
				self.warning4 = true;
			end;
		end;

		if InputBinding.hasEvent(InputBinding.FLIEGL_DPW180_TOGGLE_HELP) then
			self.showFlieglHelp = not self.showFlieglHelp;
		end;
		
		if InputBinding.hasEvent(InputBinding.FLIEGL_DPW180_TOGGLE_UNLOAD_HELP) then
			self.showUnloadingHelp = not self.showUnloadingHelp;
		end;
	end;
end;

function FlieglDPW180:updateTick(dt)
	--## set help line's for the different product's 
	if self.choosenProductType[self.productType][1] == g_i18n:getText("WOOLPALLET")
    or self.choosenProductType[self.productType][1] == g_i18n:getText("PALLET")	
	then
	
		--## set the length of the help line's to the current fill level
		if self.fillLevel < 3 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.519, 0, 2.826);
			setTranslation(self.helpLineLeftStart2, 4.3, 0, 2.826);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.519, 0, 2.826); 
			setTranslation(self.helpLineRightStart2, -4.3, 0, 2.826);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.383, 0, -9.159);
			setTranslation(self.helpLineBackEnd2, -1.383, 0, -9.159);
		elseif self.fillLevel < 5 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.665, 0, 1.1);
			setTranslation(self.helpLineLeftStart2, 4.12, 0, 1.1);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.665, 0, 1.1);
			setTranslation(self.helpLineRightStart2, -4.12, 0, 1.1);	

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.383, 0, -10.903);
			setTranslation(self.helpLineBackEnd2, -1.383, 0, -10.903);
		elseif self.fillLevel < 7 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.519, 0, -0.634);
			setTranslation(self.helpLineLeftStart2, 4.3, 0, -0.634);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.519, 0, -0.634); 
			setTranslation(self.helpLineRightStart2, -4.3, 0, -0.634);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.383, 0, -12.65);
			setTranslation(self.helpLineBackEnd2, -1.383, 0, -12.65);
		elseif self.fillLevel < 9 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.519, 0, -2.388);
			setTranslation(self.helpLineLeftStart2, 4.3, 0, -2.388);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.519, 0, -2.388); 
			setTranslation(self.helpLineRightStart2, -4.3, 0, -2.388);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.383, 0, -14.379);
			setTranslation(self.helpLineBackEnd2, -1.383, 0, -14.379);
		elseif self.fillLevel < 11 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.519, 0, -4.119);
			setTranslation(self.helpLineLeftStart2, 4.3, 0, -4.119);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.519, 0, -4.119); 
			setTranslation(self.helpLineRightStart2, -4.3, 0, -4.119);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.383, 0, -16.14);
			setTranslation(self.helpLineBackEnd2, -1.383, 0, -16.14);
		elseif self.fillLevel >= 11 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.519, 0, -5.875);
			setTranslation(self.helpLineRightStart2, -4.3, 0, -5.875);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.519, 0, -5.875); 
			setTranslation(self.helpLineRightStart2, -4.3, 0, -2.379);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.383, 0, -17.844);
			setTranslation(self.helpLineBackEnd2, -1.383, 0, -17.844);
		end;
		
		--## left help line's
		setTranslation(self.helpLineLeftEnd, 1.519, 0, 4.59);
		setTranslation(self.helpLineLeftEnd2, 4.3, 0, 4.59);
		
		--## right help line's
		setTranslation(self.helpLineRightEnd, -1.519, 0, 4.59);
		setTranslation(self.helpLineRightEnd2, -4.3, 0, 4.59);
		
		--## back help line's
		setTranslation(self.helpLineBackStart, 1.383, 0, -7.453);
		setTranslation(self.helpLineBackStart2, -1.383, 0, -7.453); 
		
	elseif self.choosenProductType[self.productType][1] == g_i18n:getText("BOARDPALLET") then
		
		--## set the length of the help line's to the current fill level
		if self.fillLevel < 3 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.556, 0, -0.48);
			setTranslation(self.helpLineLeftStart2, 4.22, 0, -0.48);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.556, 0, -0.48); 
			setTranslation(self.helpLineRightStart2, -4.22, 0, -0.48);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.35, 0, -12.49);
			setTranslation(self.helpLineBackEnd2, -1.35, 0, -12.49);
		elseif self.fillLevel >= 3 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.556, 0, -5.209);
			setTranslation(self.helpLineLeftStart2, 4.22, 0, -5.209);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.556, 0, -5.209); 
			setTranslation(self.helpLineRightStart2, -4.22, 0, -5.209);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.35, 0, -17.219);
			setTranslation(self.helpLineBackEnd2, -1.35, 0, -17.219);
		end;
		
		--## left help line's
		setTranslation(self.helpLineLeftEnd, 1.556, 0, 3.98);
		setTranslation(self.helpLineLeftEnd2, 4.22, 0, 3.98);
		
		--## right help line's
		setTranslation(self.helpLineRightEnd, -1.556, 0, 3.98);
		setTranslation(self.helpLineRightEnd2, -4.22, 0, 3.98);
		
		--## back help line's
		setTranslation(self.helpLineBackStart, 1.35, 0, -8.038);
		setTranslation(self.helpLineBackStart2, -1.35, 0, -8.038); 
		
	elseif self.choosenProductType[self.productType][1] == g_i18n:getText("WASHEDPOTATOPALLET") 
	    or self.choosenProductType[self.productType][1] == g_i18n:getText("WASHEDSUGARBEETPALLET")
		or self.choosenProductType[self.productType][1] == g_i18n:getText("CHAFFPALLET")
	then
		
		--## set the length of the help line's to the current fill level
		if self.fillLevel < 3 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.334, 0, 1.23);
			setTranslation(self.helpLineLeftStart2, 4.52, 0, 1.23);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.334, 0, 1.23); 
			setTranslation(self.helpLineRightStart2, -4.52, 0, 1.23);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.602, 0, -10.783);
			setTranslation(self.helpLineBackEnd2, -1.602, 0, -10.783);
		elseif self.fillLevel < 5 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.334, 0, -2.07);
			setTranslation(self.helpLineLeftStart2, 4.52, 0, -2.07);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.334, 0, -2.07); 
			setTranslation(self.helpLineRightStart2, -4.52, 0, -2.07);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.602, 0, -14.078);
			setTranslation(self.helpLineBackEnd2, -1.602, 0, -14.078);
		elseif self.fillLevel >= 5 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.334, 0, -5.363);
			setTranslation(self.helpLineLeftStart2, 4.52, 0, -5.363);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.334, 0, -5.363); 
			setTranslation(self.helpLineRightStart2, -4.52, 0, -5.363);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.602, 0, -17.349);
			setTranslation(self.helpLineBackEnd2, -1.602, 0, -17.349);
		end;
		
		--## left help line's
		setTranslation(self.helpLineLeftEnd, 1.334, 0, 4.343);
		setTranslation(self.helpLineLeftEnd2, 4.52, 0, 4.343);
		
		--## right help line's
		setTranslation(self.helpLineRightEnd, -1.334, 0, 4.343);
		setTranslation(self.helpLineRightEnd2, -4.52, 0, 4.343);
		
		--## back help line's
		setTranslation(self.helpLineBackStart, 1.602, 0, -7.668);
		setTranslation(self.helpLineBackStart2, -1.602, 0, -7.668); 
		
	elseif self.choosenProductType[self.productType][1] == g_i18n:getText("STRAW_SQUAREBALE") 
		or self.choosenProductType[self.productType][1] == g_i18n:getText("HAY_SQUAREBALE") 
		or self.choosenProductType[self.productType][1] == g_i18n:getText("MIX_SQUAREBALE") 
	then
	
		--## set the length of the help line's to the current fill level
		if self.fillLevel < 3 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.665, 0, 2.07);
			setTranslation(self.helpLineLeftStart2, 4.12, 0, 2.07);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.665, 0, 2.07); 
			setTranslation(self.helpLineRightStart2, -4.12, 0, 2.07);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.242, 0, -9.936);
			setTranslation(self.helpLineBackEnd2, -1.242, 0, -9.936);
		elseif self.fillLevel < 5 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.665, 0, -0.38);
			setTranslation(self.helpLineLeftStart2, 4.12, 0, -0.38);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.665, 0, -0.38); 
			setTranslation(self.helpLineRightStart2, -4.12, 0, -0.38);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.242, 0, -12.369);
			setTranslation(self.helpLineBackEnd2, -1.242, 0, -12.369);
		elseif self.fillLevel < 7 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.665, 0, -2.841);
			setTranslation(self.helpLineLeftStart2, 4.12, 0, -2.841);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.665, 0, -2.841); 
			setTranslation(self.helpLineRightStart2, -4.12, 0, -2.841);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.242, 0, -14.835);
			setTranslation(self.helpLineBackEnd2, -1.242, 0, -14.835);
		elseif self.fillLevel >= 7 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.665, 0, -5.3);
			setTranslation(self.helpLineLeftStart2, 4.12, 0, -5.3);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.665, 0, -5.3); 
			setTranslation(self.helpLineRightStart2, -4.12, 0, -5.3);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.242, 0, -17.307);
			setTranslation(self.helpLineBackEnd2, -1.242, 0, -17.307);
		end;
		
		--## left help line's
		setTranslation(self.helpLineLeftEnd, 1.665, 0, 4.5);
		setTranslation(self.helpLineLeftEnd2, 4.12, 0, 4.5);
		
		--## right help line's
		setTranslation(self.helpLineRightEnd, -1.665, 0, 4.5);
		setTranslation(self.helpLineRightEnd2, -4.12, 0, 4.5);
		
		--## back help line's
		setTranslation(self.helpLineBackStart, 1.242, 0, -7.522);
		setTranslation(self.helpLineBackStart2, -1.242, 0, -7.522); 
		
	elseif self.choosenProductType[self.productType][1] == g_i18n:getText("STRAW_ROUNDBALE") 
		or self.choosenProductType[self.productType][1] == g_i18n:getText("HAY_ROUNDBALE") 
		or self.choosenProductType[self.productType][1] == g_i18n:getText("GRASS_ROUNDBALE")
		or self.choosenProductType[self.productType][1] == g_i18n:getText("SILAGE_ROUNDBALE") 			
		or self.choosenProductType[self.productType][1] == g_i18n:getText("MIX_ROUNDBALE") 
	then
		
		--## set the length of the help line's to the current fill level
		if self.fillLevel < 3 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.726, 0, 3.74);
			setTranslation(self.helpLineLeftStart2, 4.08, 0, 3.74);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.726, 0, 3.74); 
			setTranslation(self.helpLineRightStart2, -4.08, 0, 3.74);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.182, 0, -8.258);
			setTranslation(self.helpLineBackEnd2, -1.182, 0, -8.258);
		elseif self.fillLevel < 5 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.726, 0, 2.448);
			setTranslation(self.helpLineLeftStart2, 4.08, 0, 2.448);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.726, 0, 2.448); 
			setTranslation(self.helpLineRightStart2, -4.08, 0, 2.448);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.182, 0, -9.546);
			setTranslation(self.helpLineBackEnd2, -1.182, 0, -9.546);
		elseif self.fillLevel < 7 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.726, 0, 1.144);
			setTranslation(self.helpLineLeftStart2, 4.08, 0, 1.144);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.726, 0, 1.144); 
			setTranslation(self.helpLineRightStart2, -4.08, 0, 1.144);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.182, 0, -10.837);
			setTranslation(self.helpLineBackEnd2, -1.182, 0, -10.837);
		elseif self.fillLevel < 9 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.726, 0, -0.161);
			setTranslation(self.helpLineLeftStart2, 4.08, 0, -0.161);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.726, 0, -0.161); 
			setTranslation(self.helpLineRightStart2, -4.08, 0, -0.161);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.182, 0, -12.149);
			setTranslation(self.helpLineBackEnd2, -1.182, 0, -12.149);
		elseif self.fillLevel < 11 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.726, 0, -1.539);
			setTranslation(self.helpLineLeftStart2, 4.08, 0, -1.539);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.726, 0, -1.539); 
			setTranslation(self.helpLineRightStart2, -4.08, 0, -1.539);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.182, 0, -13.453);
			setTranslation(self.helpLineBackEnd2, -1.182, 0, -13.453);
		elseif self.fillLevel < 13 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.726, 0, -2.757);
			setTranslation(self.helpLineLeftStart2, 4.08, 0, -2.757);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.726, 0, -2.757); 
			setTranslation(self.helpLineRightStart2, -4.08, 0, -2.757);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.182, 0, -14.76);
			setTranslation(self.helpLineBackEnd2, -1.182, 0, -14.76);
		elseif self.fillLevel < 15 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.726, 0, -4.054);
			setTranslation(self.helpLineLeftStart2, 4.08, 0, -4.054);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.726, 0, -4.054); 
			setTranslation(self.helpLineRightStart2, -4.08, 0, -4.054);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.182, 0, -16.047);
			setTranslation(self.helpLineBackEnd2, -1.182, 0, -16.047);
		elseif self.fillLevel >= 15 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.726, 0, -5.345);
			setTranslation(self.helpLineLeftStart2, 4.08, 0, -5.345);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.726, 0, -5.345); 
			setTranslation(self.helpLineRightStart2, -4.08, 0, -5.345);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.182, 0, -17.325);
			setTranslation(self.helpLineBackEnd2, -1.182, 0, -17.325);
		end;
		
		--## left help line's
		setTranslation(self.helpLineLeftEnd, 1.726, 0, 5.05);
		setTranslation(self.helpLineLeftEnd2, 4.08, 0, 5.05);
		
		--## right help line's 
		setTranslation(self.helpLineRightEnd, -1.726, 0, 5.05);
		setTranslation(self.helpLineRightEnd2, -4.08, 0, 5.05);
		
		--## back help line's
		setTranslation(self.helpLineBackStart, 1.182, 0, -6.952);
		setTranslation(self.helpLineBackStart2, -1.182, 0, -6.952); 
	
	elseif self.choosenProductType[self.productType][1] == g_i18n:getText("TREESAPLINGPALLET") then
		
		--## set the length of the help line's to the current fill level
		if self.fillLevel < 3 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.693, 0, 2.967);
			setTranslation(self.helpLineLeftStart2, 4.114, 0, 2.967);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.693, 0, 2.967); 
			setTranslation(self.helpLineRightStart2, -4.114, 0, 2.967);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.182, 0, -9.024);
			setTranslation(self.helpLineBackEnd2, -1.182, 0, -9.024);
		elseif self.fillLevel < 5 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.693, 0, 1.247);
			setTranslation(self.helpLineLeftStart2, 4.114, 0, 1.247);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.693, 0, 1.247); 
			setTranslation(self.helpLineRightStart2, -4.114, 0, 1.247);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.182, 0, -10.763);
			setTranslation(self.helpLineBackEnd2, -1.182, 0, -10.763);
		elseif self.fillLevel < 7 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.693, 0, -0.505);
			setTranslation(self.helpLineLeftStart2, 4.114, 0, -0.505);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.693, 0, -0.505); 
			setTranslation(self.helpLineRightStart2, -4.114, 0, -0.505);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.182, 0, -12.51);
			setTranslation(self.helpLineBackEnd2, -1.182, 0, -12.51);
		elseif self.fillLevel < 9 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.693, 0, -2.226);
			setTranslation(self.helpLineLeftStart2, 4.114, 0, -2.226);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.693, 0, -2.226); 
			setTranslation(self.helpLineRightStart2, -4.114, 0, -2.226);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.182, 0, -14.224);
			setTranslation(self.helpLineBackEnd2, -1.182, 0, -14.224);
		elseif self.fillLevel < 11 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.693, 0, -3.976);
			setTranslation(self.helpLineLeftStart2, 4.114, 0, -3.976);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.693, 0, -3.976); 
			setTranslation(self.helpLineRightStart2, -4.114, 0, -3.976);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.182, 0, -15.975);
			setTranslation(self.helpLineBackEnd2, -1.182, 0, -15.975);
		elseif self.fillLevel >= 11 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.693, 0, -5.722);
			setTranslation(self.helpLineLeftStart2, 4.114, 0, -5.722);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.693, 0, -5.722); 
			setTranslation(self.helpLineRightStart2, -4.114, 0, -5.722);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.182, 0, -17.729);
			setTranslation(self.helpLineBackEnd2, -1.182, 0, -17.729);
		end;
		
		--## left help line's
		setTranslation(self.helpLineLeftEnd, 1.693, 0, 5.05);
		setTranslation(self.helpLineLeftEnd2, 4.114, 0, 5.05);
		
		--## right help line's
		setTranslation(self.helpLineRightEnd, -1.693, 0, 5.05);
		setTranslation(self.helpLineRightEnd2, -4.114, 0, 5.05);
		
		--## back help line's
		setTranslation(self.helpLineBackStart, 1.182, 0, -7.585);
		setTranslation(self.helpLineBackStart2, -1.182, 0, -7.585); 
	
	elseif self.choosenProductType[self.productType][1] == g_i18n:getText("TRANSPORTBOX") then
		
		--## set the length of the help line's to the current fill level
		if self.fillLevel < 3 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.75, 0, 2.42);
			setTranslation(self.helpLineLeftStart2, 4.055, 0, 2.42);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.75, 0, 2.42); 
			setTranslation(self.helpLineRightStart2, -4.055, 0, 2.42);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.155, 0, -9.57);
			setTranslation(self.helpLineBackEnd2, -1.155, 0, -9.57);
		elseif self.fillLevel < 5 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.75, 0, 0.59);
			setTranslation(self.helpLineLeftStart2, 4.055, 0, 0.59);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.75, 0, 1.095); 
			setTranslation(self.helpLineRightStart2, -4.055, 0, 1.095);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.155, 0, -11.41);
			setTranslation(self.helpLineBackEnd2, -1.155, 0, -11.41);
		elseif self.fillLevel < 7 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.75, 0, -1.22);
			setTranslation(self.helpLineLeftStart2, 4.055, 0, -1.22);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.75, 0, -1.22); 
			setTranslation(self.helpLineRightStart2, -4.055, 0, -1.22);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.155, 0, -13.22);
			setTranslation(self.helpLineBackEnd2, -1.155, 0, -13.22);
		elseif self.fillLevel < 9 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.75, 0, -3.04);
			setTranslation(self.helpLineLeftStart2, 4.055, 0, -3.04);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.75, 0, -3.04); 
			setTranslation(self.helpLineRightStart2, -4.055, 0, -3.04);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.155, 0, -15.04);
			setTranslation(self.helpLineBackEnd2, -1.155, 0, -15.04);
		elseif self.fillLevel >= 9 then
			--## left help line's
			setTranslation(self.helpLineLeftStart, 1.75, 0, -4.885);
			setTranslation(self.helpLineLeftStart2, 4.055, 0, -4.885);
			
			--## right help line's
			setTranslation(self.helpLineRightStart, -1.75, 0, -4.885); 
			setTranslation(self.helpLineRightStart2, -4.055, 0, -4.885);

			--## back help line's
			setTranslation(self.helpLineBackEnd, 1.155, 0, -16.9);
			setTranslation(self.helpLineBackEnd2, -1.155, 0, -16.9);
		end;
		
		--## left help line's
		setTranslation(self.helpLineLeftEnd, 1.75, 0, 4.17);
		setTranslation(self.helpLineLeftEnd2, 4.055, 0, 4.17);
		
		--## right help line's
		setTranslation(self.helpLineRightEnd, -1.75, 0, 4.17);
		setTranslation(self.helpLineRightEnd2, -4.055, 0, 4.17);
		
		--## back help line's
		setTranslation(self.helpLineBackStart, 1.155, 0, -7.82);
		setTranslation(self.helpLineBackStart2, -1.155, 0, -7.82); 
	end;
	
	if self.fillLevel == self.capacity and self.loadingIsActive then
		self.loadingIsActive = false;
	end;
		
	if self.choosenProductType[self.productType][1] == g_i18n:getText("STRAW_SQUAREBALE") 
		or self.choosenProductType[self.productType][1] == g_i18n:getText("HAY_SQUAREBALE") 
		or self.choosenProductType[self.productType][1] == g_i18n:getText("MIX_SQUAREBALE") 
	then
		if self.fillLevel == 1 then
			setVisibility(self.spanngurt.quaderballen.ballen1, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen1, false);
		end;
		if self.fillLevel == 2 then
			setVisibility(self.spanngurt.quaderballen.ballen2, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen2, false);
		end;
		if self.fillLevel == 3 then
			setVisibility(self.spanngurt.quaderballen.ballen3, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen3, false);
		end;
		if self.fillLevel == 4 then
			setVisibility(self.spanngurt.quaderballen.ballen4, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen4, false);
		end;
		if self.fillLevel == 5 then
			setVisibility(self.spanngurt.quaderballen.ballen5, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen5, false);
		end;
		if self.fillLevel == 6 then
			setVisibility(self.spanngurt.quaderballen.ballen6, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen6, false);
		end;
		if self.fillLevel == 7 then
			setVisibility(self.spanngurt.quaderballen.ballen7, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen7, false);
		end;
		if self.fillLevel == 8 then
			setVisibility(self.spanngurt.quaderballen.ballen8, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen8, false);
		end;
		if self.fillLevel == 9 then
			setVisibility(self.spanngurt.quaderballen.ballen9, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen9, false);
		end;
		if self.fillLevel == 10 then
			setVisibility(self.spanngurt.quaderballen.ballen10, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen10, false);
		end;
		if self.fillLevel == 11 then
			setVisibility(self.spanngurt.quaderballen.ballen11, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen11, false);
		end;
		if self.fillLevel == 12 then
			setVisibility(self.spanngurt.quaderballen.ballen12, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen12, false);
		end;
		if self.fillLevel == 13 then
			setVisibility(self.spanngurt.quaderballen.ballen13, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen13, false);
		end;
		if self.fillLevel == 14 then
			setVisibility(self.spanngurt.quaderballen.ballen14, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen14, false);
		end;
		if self.fillLevel == 15 then
			setVisibility(self.spanngurt.quaderballen.ballen15, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen15, false);
		end;
		if self.fillLevel == 16 then
			setVisibility(self.spanngurt.quaderballen.ballen16, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen16, false);
		end;
		if self.fillLevel == 17 then
			setVisibility(self.spanngurt.quaderballen.ballen17, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen17, false);
		end;
		if self.fillLevel == 18 then
			setVisibility(self.spanngurt.quaderballen.ballen18, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen18, false);
		end;
		if self.fillLevel == 19 then
			setVisibility(self.spanngurt.quaderballen.ballen19, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen19, false);
		end;
		if self.fillLevel == 20 then
			setVisibility(self.spanngurt.quaderballen.ballen20, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen20, false);
		end;
		if self.fillLevel == 21 then
			setVisibility(self.spanngurt.quaderballen.ballen21, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen21, false);
		end;
		if self.fillLevel == 22 then
			setVisibility(self.spanngurt.quaderballen.ballen22, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen22, false);
		end;
		if self.fillLevel == 23 then
			setVisibility(self.spanngurt.quaderballen.ballen23, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen23, false);
		end;
		if self.fillLevel == 24 then
			setVisibility(self.spanngurt.quaderballen.ballen24, true);
		else
			setVisibility(self.spanngurt.quaderballen.ballen24, false);
		end;
	else
		setVisibility(self.spanngurt.quaderballen.ballen1, false);
		setVisibility(self.spanngurt.quaderballen.ballen2, false);
		setVisibility(self.spanngurt.quaderballen.ballen3, false);
		setVisibility(self.spanngurt.quaderballen.ballen4, false);
		setVisibility(self.spanngurt.quaderballen.ballen5, false);
		setVisibility(self.spanngurt.quaderballen.ballen6, false);
		setVisibility(self.spanngurt.quaderballen.ballen7, false);
		setVisibility(self.spanngurt.quaderballen.ballen8, false);
		setVisibility(self.spanngurt.quaderballen.ballen9, false);
		setVisibility(self.spanngurt.quaderballen.ballen10, false);
		setVisibility(self.spanngurt.quaderballen.ballen11, false);
		setVisibility(self.spanngurt.quaderballen.ballen12, false);
		setVisibility(self.spanngurt.quaderballen.ballen13, false);
		setVisibility(self.spanngurt.quaderballen.ballen14, false);
		setVisibility(self.spanngurt.quaderballen.ballen15, false);
		setVisibility(self.spanngurt.quaderballen.ballen16, false);
		setVisibility(self.spanngurt.quaderballen.ballen17, false);
		setVisibility(self.spanngurt.quaderballen.ballen18, false);
		setVisibility(self.spanngurt.quaderballen.ballen19, false);
		setVisibility(self.spanngurt.quaderballen.ballen20, false);
		setVisibility(self.spanngurt.quaderballen.ballen21, false);
		setVisibility(self.spanngurt.quaderballen.ballen22, false);
		setVisibility(self.spanngurt.quaderballen.ballen23, false);
		setVisibility(self.spanngurt.quaderballen.ballen24, false);
	end;
	if self.choosenProductType[self.productType][1] == g_i18n:getText("STRAW_ROUNDBALE") 
		or self.choosenProductType[self.productType][1] == g_i18n:getText("HAY_ROUNDBALE") 
		or self.choosenProductType[self.productType][1] == g_i18n:getText("GRASS_ROUNDBALE")
		or self.choosenProductType[self.productType][1] == g_i18n:getText("SILAGE_ROUNDBALE") 			
		or self.choosenProductType[self.productType][1] == g_i18n:getText("MIX_ROUNDBALE") 
	then
		if self.fillLevel == 1 then
			setVisibility(self.spanngurt.rundballen.ballen1, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen1, false);
		end;
		if self.fillLevel == 2 then
			setVisibility(self.spanngurt.rundballen.ballen2, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen2, false);
		end;
		if self.fillLevel == 3 then
			setVisibility(self.spanngurt.rundballen.ballen3, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen3, false);
		end;
		if self.fillLevel == 4 then
			setVisibility(self.spanngurt.rundballen.ballen4, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen4, false);
		end;
		if self.fillLevel == 5 then
			setVisibility(self.spanngurt.rundballen.ballen5, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen5, false);
		end;
		if self.fillLevel == 6 then
			setVisibility(self.spanngurt.rundballen.ballen6, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen6, false);
		end;
		if self.fillLevel == 7 then
			setVisibility(self.spanngurt.rundballen.ballen7, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen7, false);
		end;
		if self.fillLevel == 8 then
			setVisibility(self.spanngurt.rundballen.ballen8, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen8, false);
		end;
		if self.fillLevel == 9 then
			setVisibility(self.spanngurt.rundballen.ballen9, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen9, false);
		end;
		if self.fillLevel == 10 then
			setVisibility(self.spanngurt.rundballen.ballen10, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen10, false);
		end;
		if self.fillLevel == 11 then
			setVisibility(self.spanngurt.rundballen.ballen11, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen11, false);
		end;
		if self.fillLevel == 12 then
			setVisibility(self.spanngurt.rundballen.ballen12, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen12, false);
		end;
		if self.fillLevel == 13 then
			setVisibility(self.spanngurt.rundballen.ballen13, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen13, false);
		end;
		if self.fillLevel == 14 then
			setVisibility(self.spanngurt.rundballen.ballen14, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen14, false);
		end;
		if self.fillLevel == 15 then
			setVisibility(self.spanngurt.rundballen.ballen15, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen15, false);
		end;
		if self.fillLevel == 16 then
			setVisibility(self.spanngurt.rundballen.ballen16, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen16, false);
		end;
		if self.fillLevel == 17 then
			setVisibility(self.spanngurt.rundballen.ballen17, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen17, false);
		end;
		if self.fillLevel == 18 then
			setVisibility(self.spanngurt.rundballen.ballen18, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen18, false);
		end;
		if self.fillLevel == 19 then
			setVisibility(self.spanngurt.rundballen.ballen19, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen19, false);
		end;
		if self.fillLevel == 20 then
			setVisibility(self.spanngurt.rundballen.ballen20, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen20, false);
		end;
		if self.fillLevel == 21 then
			setVisibility(self.spanngurt.rundballen.ballen21, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen21, false);
		end;
		if self.fillLevel == 22 then
			setVisibility(self.spanngurt.rundballen.ballen22, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen22, false);
		end;
		if self.fillLevel == 23 then
			setVisibility(self.spanngurt.rundballen.ballen23, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen23, false);
		end;
		if self.fillLevel == 24 then
			setVisibility(self.spanngurt.rundballen.ballen24, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen24, false);
		end;
		if self.fillLevel == 25 then
			setVisibility(self.spanngurt.rundballen.ballen25, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen25, false);
		end;
		if self.fillLevel == 26 then
			setVisibility(self.spanngurt.rundballen.ballen26, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen26, false);
		end;
		if self.fillLevel == 27 then
			setVisibility(self.spanngurt.rundballen.ballen27, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen27, false);
		end;
		if self.fillLevel == 28 then
			setVisibility(self.spanngurt.rundballen.ballen28, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen28, false);
		end;
		if self.fillLevel == 29 then
			setVisibility(self.spanngurt.rundballen.ballen29, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen29, false);
		end;
		if self.fillLevel == 30 then
			setVisibility(self.spanngurt.rundballen.ballen30, true);
		else
			setVisibility(self.spanngurt.rundballen.ballen30, false);
		end;
	else
		setVisibility(self.spanngurt.rundballen.ballen1, false);
		setVisibility(self.spanngurt.rundballen.ballen2, false);
		setVisibility(self.spanngurt.rundballen.ballen3, false);
		setVisibility(self.spanngurt.rundballen.ballen4, false);
		setVisibility(self.spanngurt.rundballen.ballen5, false);
		setVisibility(self.spanngurt.rundballen.ballen6, false);
		setVisibility(self.spanngurt.rundballen.ballen7, false);
		setVisibility(self.spanngurt.rundballen.ballen8, false);
		setVisibility(self.spanngurt.rundballen.ballen9, false);
		setVisibility(self.spanngurt.rundballen.ballen10, false);
		setVisibility(self.spanngurt.rundballen.ballen11, false);
		setVisibility(self.spanngurt.rundballen.ballen12, false);
		setVisibility(self.spanngurt.rundballen.ballen13, false);
		setVisibility(self.spanngurt.rundballen.ballen14, false);
		setVisibility(self.spanngurt.rundballen.ballen15, false);
		setVisibility(self.spanngurt.rundballen.ballen16, false);
		setVisibility(self.spanngurt.rundballen.ballen17, false);
		setVisibility(self.spanngurt.rundballen.ballen18, false);
		setVisibility(self.spanngurt.rundballen.ballen19, false);
		setVisibility(self.spanngurt.rundballen.ballen20, false);
		setVisibility(self.spanngurt.rundballen.ballen21, false);
		setVisibility(self.spanngurt.rundballen.ballen22, false);
		setVisibility(self.spanngurt.rundballen.ballen23, false);
		setVisibility(self.spanngurt.rundballen.ballen24, false);
		setVisibility(self.spanngurt.rundballen.ballen25, false);
		setVisibility(self.spanngurt.rundballen.ballen26, false);
		setVisibility(self.spanngurt.rundballen.ballen27, false);
		setVisibility(self.spanngurt.rundballen.ballen28, false);
		setVisibility(self.spanngurt.rundballen.ballen29, false);
		setVisibility(self.spanngurt.rundballen.ballen30, false);
	end;
	if self.choosenProductType[self.productType][1] == g_i18n:getText("WOOLPALLET") 
	or self.choosenProductType[self.productType][1] == g_i18n:getText("PALLET")
	then
		if self.fillLevel == 1 then
			setVisibility(self.spanngurt.wollpaletten.palette1, true);
		else
			setVisibility(self.spanngurt.wollpaletten.palette1, false);
		end;
		if self.fillLevel == 2 then
			setVisibility(self.spanngurt.wollpaletten.palette2, true);
		else
			setVisibility(self.spanngurt.wollpaletten.palette2, false);
		end;
		if self.fillLevel == 3 then
			setVisibility(self.spanngurt.wollpaletten.palette3, true);
		else
			setVisibility(self.spanngurt.wollpaletten.palette3, false);
		end;
		if self.fillLevel == 4 then
			setVisibility(self.spanngurt.wollpaletten.palette4, true);
		else
			setVisibility(self.spanngurt.wollpaletten.palette4, false);
		end;
		if self.fillLevel == 5 then
			setVisibility(self.spanngurt.wollpaletten.palette5, true);
		else
			setVisibility(self.spanngurt.wollpaletten.palette5, false);
		end;
		if self.fillLevel == 6 then
			setVisibility(self.spanngurt.wollpaletten.palette6, true);
		else
			setVisibility(self.spanngurt.wollpaletten.palette6, false);
		end;
		if self.fillLevel == 7 then
			setVisibility(self.spanngurt.wollpaletten.palette7, true);
		else
			setVisibility(self.spanngurt.wollpaletten.palette7, false);
		end;
		if self.fillLevel == 8 then
			setVisibility(self.spanngurt.wollpaletten.palette8, true);
		else
			setVisibility(self.spanngurt.wollpaletten.palette8, false);
		end;
		if self.fillLevel == 9 then
			setVisibility(self.spanngurt.wollpaletten.palette9, true);
		else
			setVisibility(self.spanngurt.wollpaletten.palette9, false);
		end;
		if self.fillLevel == 10 then
			setVisibility(self.spanngurt.wollpaletten.palette10, true);
		else
			setVisibility(self.spanngurt.wollpaletten.palette10, false);
		end;
		if self.fillLevel == 11 then
			setVisibility(self.spanngurt.wollpaletten.palette11, true);
		else
			setVisibility(self.spanngurt.wollpaletten.palette11, false);
		end;
		if self.fillLevel == 12 then
			setVisibility(self.spanngurt.wollpaletten.palette12, true);
		else
			setVisibility(self.spanngurt.wollpaletten.palette12, false);
		end;
	else
		setVisibility(self.spanngurt.wollpaletten.palette1, false);
		setVisibility(self.spanngurt.wollpaletten.palette2, false);
		setVisibility(self.spanngurt.wollpaletten.palette3, false);
		setVisibility(self.spanngurt.wollpaletten.palette4, false);
		setVisibility(self.spanngurt.wollpaletten.palette5, false);
		setVisibility(self.spanngurt.wollpaletten.palette6, false);
		setVisibility(self.spanngurt.wollpaletten.palette7, false);
		setVisibility(self.spanngurt.wollpaletten.palette8, false);
		setVisibility(self.spanngurt.wollpaletten.palette9, false);
		setVisibility(self.spanngurt.wollpaletten.palette10, false);
		setVisibility(self.spanngurt.wollpaletten.palette11, false);
		setVisibility(self.spanngurt.wollpaletten.palette12, false);
	end;
	if self.choosenProductType[self.productType][1] == g_i18n:getText("TREESAPLINGPALLET") then
		if self.fillLevel == 1 then
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette1, true);
		else
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette1, false);
		end;
		if self.fillLevel == 2 then
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette2, true);
		else
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette2, false);
		end;
		if self.fillLevel == 3 then
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette3, true);
		else
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette3, false);
		end;
		if self.fillLevel == 4 then
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette4, true);
		else
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette4, false);
		end;
		if self.fillLevel == 5 then
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette5, true);
		else
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette5, false);
		end;
		if self.fillLevel == 6 then
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette6, true);
		else
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette6, false);
		end;
		if self.fillLevel == 7 then
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette7, true);
		else
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette7, false);
		end;
		if self.fillLevel == 8 then
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette8, true);
		else
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette8, false);
		end;
		if self.fillLevel == 9 then
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette9, true);
		else
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette9, false);
		end;
		if self.fillLevel == 10 then
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette10, true);
		else
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette10, false);
		end;
		if self.fillLevel == 11 then
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette11, true);
		else
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette11, false);
		end;
		if self.fillLevel == 12 then
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette12, true);
		else
			setVisibility(self.spanngurt.baumsetzlingpaletten.palette12, false);
		end;
	else
		setVisibility(self.spanngurt.baumsetzlingpaletten.palette1, false);
		setVisibility(self.spanngurt.baumsetzlingpaletten.palette2, false);
		setVisibility(self.spanngurt.baumsetzlingpaletten.palette3, false);
		setVisibility(self.spanngurt.baumsetzlingpaletten.palette4, false);
		setVisibility(self.spanngurt.baumsetzlingpaletten.palette5, false);
		setVisibility(self.spanngurt.baumsetzlingpaletten.palette6, false);
		setVisibility(self.spanngurt.baumsetzlingpaletten.palette7, false);
		setVisibility(self.spanngurt.baumsetzlingpaletten.palette8, false);
		setVisibility(self.spanngurt.baumsetzlingpaletten.palette9, false);
		setVisibility(self.spanngurt.baumsetzlingpaletten.palette10, false);
		setVisibility(self.spanngurt.baumsetzlingpaletten.palette11, false);
		setVisibility(self.spanngurt.baumsetzlingpaletten.palette12, false);
	end;
	if self.choosenProductType[self.productType][1] == g_i18n:getText("BOARDPALLET") then
		if self.fillLevel == 1 then
			setVisibility(self.spanngurt.holzpaletten.palette1, true);
		else
			setVisibility(self.spanngurt.holzpaletten.palette1, false);
		end;
		if self.fillLevel == 2 then
			setVisibility(self.spanngurt.holzpaletten.palette2, true);
		else
			setVisibility(self.spanngurt.holzpaletten.palette2, false);
		end;
		if self.fillLevel == 3 then
			setVisibility(self.spanngurt.holzpaletten.palette3, true);
		else
			setVisibility(self.spanngurt.holzpaletten.palette3, false);
		end;
		if self.fillLevel == 4 then
			setVisibility(self.spanngurt.holzpaletten.palette4, true);
		else
			setVisibility(self.spanngurt.holzpaletten.palette4, false);
		end;
		if self.fillLevel == 5 then
			setVisibility(self.spanngurt.holzpaletten.palette5, true);
		else
			setVisibility(self.spanngurt.holzpaletten.palette5, false);
		end;
		if self.fillLevel == 6 then
			setVisibility(self.spanngurt.holzpaletten.palette6, true);
		else
			setVisibility(self.spanngurt.holzpaletten.palette6, false);
		end;
		if self.fillLevel == 7 then
			setVisibility(self.spanngurt.holzpaletten.palette7, true);
		else
			setVisibility(self.spanngurt.holzpaletten.palette7, false);
		end;
		if self.fillLevel == 8 then
			setVisibility(self.spanngurt.holzpaletten.palette8, true);
		else
			setVisibility(self.spanngurt.holzpaletten.palette8, false);
		end;
	else
		setVisibility(self.spanngurt.holzpaletten.palette1, false);
		setVisibility(self.spanngurt.holzpaletten.palette2, false);
		setVisibility(self.spanngurt.holzpaletten.palette3, false);
		setVisibility(self.spanngurt.holzpaletten.palette4, false);
		setVisibility(self.spanngurt.holzpaletten.palette5, false);
		setVisibility(self.spanngurt.holzpaletten.palette6, false);
		setVisibility(self.spanngurt.holzpaletten.palette7, false);
		setVisibility(self.spanngurt.holzpaletten.palette8, false);
	end;
	if self.choosenProductType[self.productType][1] == g_i18n:getText("WASHEDPOTATOPALLET")
    or self.choosenProductType[self.productType][1] == g_i18n:getText("WASHEDSUGARBEETPALLET")
    or self.choosenProductType[self.productType][1] == g_i18n:getText("CHAFFPALLET")	
	then
		if self.fillLevel == 1 then
			setVisibility(self.spanngurt.kartoffelpaletten.palette1, true);
		else
			setVisibility(self.spanngurt.kartoffelpaletten.palette1, false);
		end;
		if self.fillLevel == 2 then
			setVisibility(self.spanngurt.kartoffelpaletten.palette2, true);
		else
			setVisibility(self.spanngurt.kartoffelpaletten.palette2, false);
		end;
		if self.fillLevel == 3 then
			setVisibility(self.spanngurt.kartoffelpaletten.palette3, true);
		else
			setVisibility(self.spanngurt.kartoffelpaletten.palette3, false);
		end;
		if self.fillLevel == 4 then
			setVisibility(self.spanngurt.kartoffelpaletten.palette4, true);
		else
			setVisibility(self.spanngurt.kartoffelpaletten.palette4, false);
		end;
		if self.fillLevel == 5 then
			setVisibility(self.spanngurt.kartoffelpaletten.palette5, true);
		else
			setVisibility(self.spanngurt.kartoffelpaletten.palette5, false);
		end;
		if self.fillLevel == 6 then
			setVisibility(self.spanngurt.kartoffelpaletten.palette6, true);
		else
			setVisibility(self.spanngurt.kartoffelpaletten.palette6, false);
		end;
		if self.fillLevel == 7 then
			setVisibility(self.spanngurt.kartoffelpaletten.palette7, true);
		else
			setVisibility(self.spanngurt.kartoffelpaletten.palette7, false);
		end;
		if self.fillLevel == 8 then
			setVisibility(self.spanngurt.kartoffelpaletten.palette8, true);
		else
			setVisibility(self.spanngurt.kartoffelpaletten.palette8, false);
		end;
		if self.fillLevel == 9 then
			setVisibility(self.spanngurt.kartoffelpaletten.palette9, true);
		else
			setVisibility(self.spanngurt.kartoffelpaletten.palette9, false);
		end;
		if self.fillLevel == 10 then
			setVisibility(self.spanngurt.kartoffelpaletten.palette10, true);
		else
			setVisibility(self.spanngurt.kartoffelpaletten.palette10, false);
		end;
		if self.fillLevel == 11 then
			setVisibility(self.spanngurt.kartoffelpaletten.palette11, true);
		else
			setVisibility(self.spanngurt.kartoffelpaletten.palette11, false);
		end;
		if self.fillLevel == 12 then
			setVisibility(self.spanngurt.kartoffelpaletten.palette11, true);
		else
			setVisibility(self.spanngurt.kartoffelpaletten.palette11, false);
		end;
	else
		setVisibility(self.spanngurt.kartoffelpaletten.palette1, false);
		setVisibility(self.spanngurt.kartoffelpaletten.palette2, false);
		setVisibility(self.spanngurt.kartoffelpaletten.palette3, false);
		setVisibility(self.spanngurt.kartoffelpaletten.palette4, false);
		setVisibility(self.spanngurt.kartoffelpaletten.palette5, false);
		setVisibility(self.spanngurt.kartoffelpaletten.palette6, false);
		setVisibility(self.spanngurt.kartoffelpaletten.palette7, false);
		setVisibility(self.spanngurt.kartoffelpaletten.palette8, false);
		setVisibility(self.spanngurt.kartoffelpaletten.palette9, false);
		setVisibility(self.spanngurt.kartoffelpaletten.palette10, false);
		setVisibility(self.spanngurt.kartoffelpaletten.palette11, false);
		setVisibility(self.spanngurt.kartoffelpaletten.palette12, false);
	end;
	if self.choosenProductType[self.productType][1] == g_i18n:getText("TRANSPORTBOX") then
		if self.fillLevel == 1 then
			setVisibility(self.spanngurt.transportboxen.box1, true);
		else
			setVisibility(self.spanngurt.transportboxen.box1, false);
		end;
		if self.fillLevel == 2 then
			setVisibility(self.spanngurt.transportboxen.box2, true);
		else
			setVisibility(self.spanngurt.transportboxen.box2, false);
		end;
		if self.fillLevel == 3 then
			setVisibility(self.spanngurt.transportboxen.box3, true);
		else
			setVisibility(self.spanngurt.transportboxen.box3, false);
		end;
		if self.fillLevel == 4 then
			setVisibility(self.spanngurt.transportboxen.box4, true);
		else
			setVisibility(self.spanngurt.transportboxen.box4, false);
		end;
		if self.fillLevel == 5 then
			setVisibility(self.spanngurt.transportboxen.box5, true);
		else
			setVisibility(self.spanngurt.transportboxen.box5, false);
		end;
		if self.fillLevel == 6 then
			setVisibility(self.spanngurt.transportboxen.box6, true);
		else
			setVisibility(self.spanngurt.transportboxen.box6, false);
		end;
		if self.fillLevel == 7 then
			setVisibility(self.spanngurt.transportboxen.box7, true);
		else
			setVisibility(self.spanngurt.transportboxen.box7, false);
		end;
		if self.fillLevel == 8 then
			setVisibility(self.spanngurt.transportboxen.box8, true);
		else
			setVisibility(self.spanngurt.transportboxen.box8, false);
		end;
		if self.fillLevel == 9 then
			setVisibility(self.spanngurt.transportboxen.box9, true);
		else
			setVisibility(self.spanngurt.transportboxen.box9, false);
		end;
		if self.fillLevel == 10 then
			setVisibility(self.spanngurt.transportboxen.box10, true);
		else
			setVisibility(self.spanngurt.transportboxen.box10, false);
		end;
		if self.fillLevel == 11 then
			setVisibility(self.spanngurt.transportboxen.box11, true);
		else
			setVisibility(self.spanngurt.transportboxen.box11, false);
		end;
		if self.fillLevel == 12 then
			setVisibility(self.spanngurt.transportboxen.box12, true);
		else
			setVisibility(self.spanngurt.transportboxen.box12, false);
		end;
		if self.fillLevel == 13 then
			setVisibility(self.spanngurt.transportboxen.box13, true);
		else
			setVisibility(self.spanngurt.transportboxen.box13, false);
		end;
		if self.fillLevel == 14 then
			setVisibility(self.spanngurt.transportboxen.box14, true);
		else
			setVisibility(self.spanngurt.transportboxen.box14, false);
		end;
		if self.fillLevel == 15 then
			setVisibility(self.spanngurt.transportboxen.box15, true);
		else
			setVisibility(self.spanngurt.transportboxen.box15, false);
		end;
		if self.fillLevel == 16 then
			setVisibility(self.spanngurt.transportboxen.box16, true);
		else
			setVisibility(self.spanngurt.transportboxen.box16, false);
		end;
		if self.fillLevel == 17 then
			setVisibility(self.spanngurt.transportboxen.box17, true);
		else
			setVisibility(self.spanngurt.transportboxen.box17, false);
		end;
		if self.fillLevel == 18 then
			setVisibility(self.spanngurt.transportboxen.box18, true);
		else
			setVisibility(self.spanngurt.transportboxen.box18, false);
		end;
		if self.fillLevel == 19 then
			setVisibility(self.spanngurt.transportboxen.box19, true);
		else
			setVisibility(self.spanngurt.transportboxen.box19, false);
		end;
		if self.fillLevel == 20 then
			setVisibility(self.spanngurt.transportboxen.box20, true);
		else
			setVisibility(self.spanngurt.transportboxen.box20, false);
		end;
	else
		setVisibility(self.spanngurt.transportboxen.box1, false);
		setVisibility(self.spanngurt.transportboxen.box2, false);
		setVisibility(self.spanngurt.transportboxen.box3, false);
		setVisibility(self.spanngurt.transportboxen.box4, false);
		setVisibility(self.spanngurt.transportboxen.box5, false);
		setVisibility(self.spanngurt.transportboxen.box6, false);
		setVisibility(self.spanngurt.transportboxen.box7, false);
		setVisibility(self.spanngurt.transportboxen.box8, false);
		setVisibility(self.spanngurt.transportboxen.box9, false);
		setVisibility(self.spanngurt.transportboxen.box10, false);
		setVisibility(self.spanngurt.transportboxen.box11, false);
		setVisibility(self.spanngurt.transportboxen.box12, false);
		setVisibility(self.spanngurt.transportboxen.box13, false);
		setVisibility(self.spanngurt.transportboxen.box14, false);
		setVisibility(self.spanngurt.transportboxen.box15, false);
		setVisibility(self.spanngurt.transportboxen.box16, false);
		setVisibility(self.spanngurt.transportboxen.box17, false);
		setVisibility(self.spanngurt.transportboxen.box18, false);
		setVisibility(self.spanngurt.transportboxen.box19, false);
		setVisibility(self.spanngurt.transportboxen.box20, false);
	end;
	
	local i = self.fillLevel + 1;
	if self.automaticLoading and (self.loadingIsActive or self.isLookingForBales) then
		self.nearestObject = FlieglDPW180:ProductInRangeFlieglDPW180(self, i);
	end
	if self.automaticLoading and self.loadingIsActive then		
		if self.attacher[self.productType][i].attachedProduct == nil then
			if self.nearestObject ~= nil then
				self.attacher[self.productType][i].productInRange = self.nearestObject;
				FlieglDPW180:ProductAttachFlieglDPW180(self, i);
			end;
		end;
	end;
end;

function FlieglDPW180:draw()
	local autoLoadText = "unknown";
	local warningText = "unknown";
	
	if self.automaticLoading then
		autoLoadText = self.automaticLoadingText[2];
	else
		autoLoadText = self.automaticLoadingText[1];
	end;
	
	if self.warning1 then
		warningText = self.warningText[1];
	elseif self.warning2 then
		warningText = self.warningText[2];
	elseif self.warning3 then
		warningText = self.warningText[3];
	elseif self.warning4 then
		warningText = self.warningText[4];
	elseif self.warning5 then
		warningText = self.warningText[5];
	elseif self.warning6 then
		warningText = self.warningText[6];
	end;
	
	if self.showWarning then
		g_currentMission:showBlinkingWarning(warningText, 3500);
	end;
	
	if self.showFlieglHelp then
		g_currentMission:addExtraPrintText(string.format(g_i18n:getText("FLIEGL_DPW180_LOADING_TYPE"), autoLoadText));
		g_currentMission:addExtraPrintText(string.format(g_i18n:getText("FLIEGL_DPW180_CHOOSEN_PRODUCTTYPE"), self.choosenProductType[self.productType][1]));
	
		if self.automaticLoading then
			if self.loadingIsActive then
				g_currentMission:addHelpButtonText(g_i18n:getText("FLIEGL_DPW180_STOP_AUTOLOAD"), InputBinding.FLIEGL_DPW180_LOAD);
				
				if self.fillLevel > 0 then
					g_currentMission:addExtraPrintText(g_i18n:getText("FLIEGL_DPW180_STOP_AUTOLOAD_TO_UNLOAD"));
				end;
			else
				if self.fillLevel < self.capacity then
					g_currentMission:addHelpButtonText(g_i18n:getText("FLIEGL_DPW180_START_AUTOLOAD"), InputBinding.FLIEGL_DPW180_LOAD);
					g_currentMission:addHelpButtonText(g_i18n:getText("FLIEGL_DPW180_TOGGLE_LOADING_TYPE"), InputBinding.FLIEGL_DPW180_TOGGLE_LOADING_TYPE);
				end;
			end;
		else
			if self.fillLevel < self.capacity then
				g_currentMission:addHelpButtonText(g_i18n:getText("FLIEGL_DPW180_LOAD"), InputBinding.FLIEGL_DPW180_LOAD);
				g_currentMission:addHelpButtonText(g_i18n:getText("FLIEGL_DPW180_TOGGLE_LOADING_TYPE"), InputBinding.FLIEGL_DPW180_TOGGLE_LOADING_TYPE);
			end;
		end;
		
		if self.fillLevel > 0 and not self.loadingIsActive then
			g_currentMission:addHelpButtonText(g_i18n:getText("FLIEGL_DPW180_UNLOAD"), InputBinding.FLIEGL_DPW180_UNLOAD);
			g_currentMission:addHelpButtonText(g_i18n:getText("FLIEGL_DPW180_TOGGLE_UNLOAD_SIDE"), InputBinding.FLIEGL_DPW180_TOGGLE_UNLOAD_SIDE);
			g_currentMission:addExtraPrintText(string.format(g_i18n:getText("FLIEGL_DPW180_UNLOAD_MODE"), self.currentUnloadSide[self.unloadSide][1]));
			
			if self.showUnloadingHelp then
				g_currentMission:addHelpButtonText(g_i18n:getText("FLIEGL_DPW180_HIDE_UNLOADING_HELP"), InputBinding.FLIEGL_DPW180_TOGGLE_UNLOAD_HELP);
				
				local xStart, yStart, zStart;
				local xEnd, yEnd, zEnd;
				local xStart2, yStart2, zStart2;
				local xEnd2, yEnd2, zEnd2
				local xStart3, yStart3, zStart3;
				local xEnd3, yEnd3, zEnd3;
				local xStart4, yStart4, zStart4;
				local xEnd4, yEnd4, zEnd4;
				
				if self.currentUnloadSide[self.unloadSide][1] == g_i18n:getText("UNLOAD_LEFT") then
					--## help line's left
					xStart, yStart, zStart = getWorldTranslation(self.helpLineLeftStart);
					xEnd, yEnd, zEnd = getWorldTranslation(self.helpLineLeftEnd);
					xStart2, yStart2, zStart2 = getWorldTranslation(self.helpLineLeftStart2);
					xEnd2, yEnd2, zEnd2 = getWorldTranslation(self.helpLineLeftEnd2);
					
					xStart3, yStart3, zStart3 = getWorldTranslation(self.helpLineLeftStart);
					xEnd3, yEnd3, zEnd3 = getWorldTranslation(self.helpLineLeftStart2);
					xStart4, yStart4, zStart4 = getWorldTranslation(self.helpLineLeftEnd);
					xEnd4, yEnd4, zEnd4 = getWorldTranslation(self.helpLineLeftEnd2);
				
				elseif self.currentUnloadSide[self.unloadSide][1] == g_i18n:getText("UNLOAD_RIGHT") then
					--## help line's right
					xStart, yStart, zStart = getWorldTranslation(self.helpLineRightStart);
					xEnd, yEnd, zEnd = getWorldTranslation(self.helpLineRightEnd);
					xStart2, yStart2, zStart2 = getWorldTranslation(self.helpLineRightStart2);
					xEnd2, yEnd2, zEnd2 = getWorldTranslation(self.helpLineRightEnd2);
					
					xStart3, yStart3, zStart3 = getWorldTranslation(self.helpLineRightStart);
					xEnd3, yEnd3, zEnd3 = getWorldTranslation(self.helpLineRightStart2);
					xStart4, yStart4, zStart4 = getWorldTranslation(self.helpLineRightEnd);
					xEnd4, yEnd4, zEnd4 = getWorldTranslation(self.helpLineRightEnd2);
				
				elseif self.currentUnloadSide[self.unloadSide][1] == g_i18n:getText("UNLOAD_BACK") then
					--## help line's back
					xStart, yStart, zStart = getWorldTranslation(self.helpLineBackStart);
					xEnd, yEnd, zEnd = getWorldTranslation(self.helpLineBackEnd);
					xStart2, yStart2, zStart2 = getWorldTranslation(self.helpLineBackStart2);
					xEnd2, yEnd2, zEnd2 = getWorldTranslation(self.helpLineBackEnd2);
					
					xStart3, yStart3, zStart3 = getWorldTranslation(self.helpLineBackStart);
					xEnd3, yEnd3, zEnd3 = getWorldTranslation(self.helpLineBackStart2);
					xStart4, yStart4, zStart4 = getWorldTranslation(self.helpLineBackEnd);
					xEnd4, yEnd4, zEnd4 = getWorldTranslation(self.helpLineBackEnd2);
				end;
				
				--## render help line's
				drawDebugLine(xStart, yStart, zStart, self.colorRed, self.colorGreen, self.colorBlue, xEnd, yEnd, zEnd, self.colorRed, self.colorGreen, self.colorBlue);
				drawDebugLine(xStart2, yStart2, zStart2, self.colorRed, self.colorGreen, self.colorBlue, xEnd2, yEnd2, zEnd2, self.colorRed, self.colorGreen, self.colorBlue);
				
				drawDebugLine(xStart3, yStart3, zStart3, self.colorRed, self.colorGreen, self.colorBlue, xEnd3, yEnd3, zEnd3, self.colorRed, self.colorGreen, self.colorBlue);
				drawDebugLine(xStart4, yStart4, zStart4, self.colorRed, self.colorGreen, self.colorBlue, xEnd4, yEnd4, zEnd4, self.colorRed, self.colorGreen, self.colorBlue);
			else
				g_currentMission:addHelpButtonText(g_i18n:getText("FLIEGL_DPW180_SHOW_UNLOADING_HELP"), InputBinding.FLIEGL_DPW180_TOGGLE_UNLOAD_HELP);
			end;
		end;
		
		if self.fillLevel == 0 then
			g_currentMission:addHelpButtonText(g_i18n:getText("FLIEGL_DPW180_TOGGLE_PRODUCT_TYPE"), InputBinding.FLIEGL_DPW180_TOGGLE_PRODUCT_TYPE);
		end;
		
		g_currentMission:addHelpButtonText(g_i18n:getText("FLIEGL_DPW180_HIDE_HELP"), InputBinding.FLIEGL_DPW180_TOGGLE_HELP);
	else
		g_currentMission:addHelpButtonText(g_i18n:getText("FLIEGL_DPW180_SHOW_HELP"), InputBinding.FLIEGL_DPW180_TOGGLE_HELP);
	end;
end;

function FlieglDPW180:ProductInRangeFlieglDPW180(self, k)
	local nearestObject;
	local index;
	local nearestDistance = self.nearestDistance;
	local objectCopy = self.attacher[self.productType][k].object;
	local px, py, pz = getWorldTranslation(objectCopy);
	
	for index, vehicle in pairs(g_currentMission.vehicles) do
		local vehicleNode = vehicle.rootNode;
		
		if getParent(vehicleNode) == getRootNode() then
			local vx, vy, vz = getWorldTranslation(vehicleNode);
			local distance = Utils.vector3Length(px-vx, py-vy, pz-vz);
	
			if self.choosenProductType[self.productType][1] == g_i18n:getText("TRANSPORTBOX") then
				if vehicle.typeName == "aaa_ROS_Palette_Box.ROSbox" then
					if vehicle.attacherJoint == nil then -- ## do not steal a box from an frontloader or tractor, when it is attached on it ..
						if distance < nearestDistance then
							index = index;
							nearestObject = vehicleNode;
							nearestDistance = distance;
						end;
					end;
				end;
			end;
		end;
	end;
	
	for index, item in pairs(g_currentMission.itemsToSave) do
		local itemNode = item.item.nodeId;
		
		if getParent(itemNode) == getRootNode() then
			local vx, vy, vz = getWorldTranslation(itemNode);
			local distance = Utils.vector3Length(px-vx, py-vy, pz-vz);
			
			if distance < nearestDistance then
				local fillType = Utils.getNoNil(getUserAttribute(itemNode, "fillType"), "wheat_windrow");
				local capacity = item.item.capacity;
				local fillLevel = item.item.fillLevel;
				local isRoundbale = Utils.getNoNil(getUserAttribute(itemNode, "isRoundbale"), false);
				local isSquarebale = Utils.getNoNil(getUserAttribute(itemNode, "isSquarebale"), false);
				local wrappingState = item.item.wrappingState;
				local filename = item.item.i3dFilename;
				local isTreeSaplingPallet = Utils.getNoNil(getUserAttribute(itemNode, "deleteIfEmpty"), false);
				
				--## fix typing mistake by GIANTS in the UserAttribute 'fillType' from the straw roundbales ..
				if fillType == "wheat_wiindrow" then
					fillType = "wheat_windrow";
				end;
				
				if self.choosenProductType[self.productType][1] == g_i18n:getText("STRAW_SQUAREBALE") then
					if filename == "data/maps/models/objects/squarebales/baleStraw240.i3d" or isSquarebale then
						if fillType == "wheat_windrow" then
							index = index;
							nearestObject = itemNode;
							nearestDistance = distance;
						end;
					end;
				elseif self.choosenProductType[self.productType][1] == g_i18n:getText("HAY_SQUAREBALE") then
					if filename == "data/maps/models/objects/squarebales/baleHay240.i3d" or isSquarebale then
						if fillType == "dryGrass_windrow" then
							index = index;
							nearestObject = itemNode;
							nearestDistance = distance;
						end;
					end;
				elseif self.choosenProductType[self.productType][1] == g_i18n:getText("MIX_SQUAREBALE") then
					if filename == ("data/maps/models/objects/squarebales/baleStraw240.i3d" or "data/maps/models/objects/squarebales/baleHay240.i3d") or isSquarebale then
						index = index;
						nearestObject = itemNode;
						nearestDistance = distance;
					end;
				elseif self.choosenProductType[self.productType][1] == g_i18n:getText("STRAW_ROUNDBALE") then
					if isRoundbale then
						if fillType == "wheat_windrow" then
							index = index;
							nearestObject = itemNode;
							nearestDistance = distance;
						end;
					end;
				elseif self.choosenProductType[self.productType][1] == g_i18n:getText("HAY_ROUNDBALE") then
					if isRoundbale then
						if fillType == "dryGrass_windrow" and wrappingState == 0 then
							index = index;
							nearestObject = itemNode;
							nearestDistance = distance;
						end;
					end;
				elseif self.choosenProductType[self.productType][1] == g_i18n:getText("GRASS_ROUNDBALE") then
					if isRoundbale then
						if fillType == "grass_windrow" and wrappingState == 0 then
							index = index;
							nearestObject = itemNode;
							nearestDistance = distance;
						end;
					end;
				elseif self.choosenProductType[self.productType][1] == g_i18n:getText("SILAGE_ROUNDBALE") then
					if isRoundbale then
						if wrappingState == 1 then
							index = index;
							nearestObject = itemNode;
							nearestDistance = distance;
						end;
					end;
				elseif self.choosenProductType[self.productType][1] == g_i18n:getText("MIX_ROUNDBALE") then
					if isRoundbale then
						index = index;
						nearestObject = itemNode;
						nearestDistance = distance;
					end;
				elseif self.choosenProductType[self.productType][1] == g_i18n:getText("WOOLPALLET") then
					if filename == "data/maps/models/objects/pallets/woolPallet.i3d" and fillLevel == capacity then
						index = index;
						nearestObject = itemNode;
						nearestDistance = distance;
					end;
				elseif self.choosenProductType[self.productType][1] == g_i18n:getText("TREESAPLINGPALLET") then
					if isTreeSaplingPallet then
						index = index;
						nearestObject = itemNode;
						nearestDistance = distance;
					end;
				elseif self.choosenProductType[self.productType][1] == g_i18n:getText("BOARDPALLET") then 
					--## support for marhu's board pallet's
					if fillType == "woodChips" and fillLevel == capacity then
						index = index;
						nearestObject = itemNode;
						nearestDistance = distance;
					end;
				elseif self.choosenProductType[self.productType][1] == g_i18n:getText("WASHEDPOTATOPALLET") then 
					--## support for Farmer_Andy's washed potato pallet's
					if fillType == "washedPotato" then
						index = index;
						nearestObject = itemNode;
						nearestDistance = distance;
					end;
					elseif self.choosenProductType[self.productType][1] == g_i18n:getText("WASHEDSUGARBEET") then 
					--## support for Farmer_Andy's washed sugarbeet pallet's
					if fillType == "washedsugarBeet" then
						index = index;
						nearestObject = itemNode;
						nearestDistance = distance;
					end;
					elseif self.choosenProductType[self.productType][1] == g_i18n:getText("CHAFFPALLET") then 
					--## support for Farmer_Andy's washed chaff pallet's
					if fillType == "chaff" 
					or fillType == "compost"then
						index = index;
						nearestObject = itemNode;
						nearestDistance = distance;
					end;
					elseif self.choosenProductType[self.productType][1] == g_i18n:getText("PALLET") then 
					--## support for greenhouse pallets and many other pallets .. 
					if fillType == "raspberry" 
						or fillType == "strawberry"
						or fillType == "cabbage"
						or fillType == "cauliflower"
						or fillType == "tomato"
						or fillType == "lettuce"
						or fillType == "egg"
						or fillType == "meat"
						or fillType == "ham"
						or fillType == "salami"
						or fillType == "beer"
						or fillType == "carrot"
						or fillType == "onion"
						or fillType == "sunflower"
						or fillType == "compost"
						or fillType == "emptypallet"
						or fillType == "cardboardpackage"
						or fillType == "redCabbage"
						or fillType == "pumpkin"
						or fillType == "steak" then
						index = index;
						nearestObject = itemNode;
						nearestDistance = distance;
					end;
				end;
			end;
		end;
	end;

	return nearestObject;
end;

function FlieglDPW180:ProductAttachFlieglDPW180(self, k)
	local x, y, z = getWorldRotation(self.attacher[self.productType][k].productInRange);
	
	setTranslation(self.attacher[self.productType][k].productInRange, 0, 0, 0);
	setRotation(self.attacher[self.productType][k].productInRange, 0, 0, 0);
	removeFromPhysics(self.attacher[self.productType][k].productInRange);
	link(self.attacher[self.productType][k].object, self.attacher[self.productType][k].productInRange);
	self.attacher[self.productType][k].attachedProduct = self.attacher[self.productType][k].productInRange;
	self.attacher[self.productType][k].productInRange = nil;
	self.fillLevel = self.fillLevel + 1;
end;

function FlieglDPW180:ProductDetachFlieglDPW180(self, k)
	if self.attacher[self.productType][k].attachedProduct ~= nil then
		if self.currentUnloadSide[self.unloadSide][1] == g_i18n:getText("UNLOAD_TRAILER") then
			local x, y, z = getWorldTranslation(self.attacher[self.productType][k].attachedProduct);
			local rx, ry, rz = getWorldRotation(self.attacher[self.productType][k].attachedProduct);
			local root = getRootNode();
			
			setTranslation(self.attacher[self.productType][k].attachedProduct, x, y, z);
			setRotation(self.attacher[self.productType][k].attachedProduct, rx, ry, rz);
			addToPhysics(self.attacher[self.productType][k].attachedProduct);
			link(root, self.attacher[self.productType][k].attachedProduct);
			self.attacher[self.productType][k].attachedProduct = nil;
		else
			local x, y, z = getWorldTranslation(self.attacher[self.productType][k].attachedProduct);
			local rx, ry, rz = getWorldRotation(self.attacher[self.productType][k].attachedProduct);
			local nx, ny, nz = getWorldTranslation(self.attacherLevel[self.productType]);
			local tx, ty, tz = getWorldTranslation(self.currentUnloadSide[self.unloadSide][3]);
			local x = x + (tx - nx);
			local y = y + (ty - ny);
			local z = z + (tz - nz);
			local tH = getTerrainHeightAtWorldPos(g_currentMission.terrainRootNode, x, y, z);
			local relHeight = ny - tH;
			local root = getRootNode();
			
			setTranslation(self.attacher[self.productType][k].attachedProduct, x, (y - relHeight), z);
			setRotation(self.attacher[self.productType][k].attachedProduct, rx, ry, rz);
			addToPhysics(self.attacher[self.productType][k].attachedProduct);
			link(root, self.attacher[self.productType][k].attachedProduct);
			self.attacher[self.productType][k].attachedProduct = nil;
		end;
	end;
end;

function FlieglDPW180:onDetach()
	if self.loadingIsActive then
		self.loadingIsActive = false;
	end;
end;

function FlieglDPW180:onLeave()
	if self.loadingIsActive then
		self.loadingIsActive = false;
	end;
end;